@@ -2,5 +2,4 @@ from node.interfaces import INode
 
 
 class IZODBNode(INode):
-    """Marker for ZODB nodes.
-    """
+    """Marker for ZODB nodes."""
